@@ -161,6 +161,7 @@ do { \
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14)
 #define PMSG_EVENT(pmsg_state) (pmsg_state).event
+#define PM_EVENT_SUSPEND 2
 #else
 #define PMSG_EVENT(pmsg_state) (pmsg_state)
 #define PM_EVENT_SUSPEND 3
@@ -556,6 +557,7 @@ extern void ATI_API_CALL firegl_pm_restore_onchip_ram(struct drm_device* dev);
 extern void ATI_API_CALL firegl_pm_restore_atigart(struct drm_device* dev);
 extern void ATI_API_CALL firegl_pm_disable_interrupts(struct drm_device* dev);
 extern void ATI_API_CALL firegl_pm_enable_interrupts(struct drm_device* dev);
+extern void ATI_API_CALL firegl_pm_lock_highmem_gart(struct drm_device* dev, int lock);
 
 /*****************************************************************************/
 
